@@ -10,5 +10,5 @@ pub const CONFIGURATOR_HELLO_EVENT_CODE: u16 = 0x0005;
 
 pub const BCM_CHANGE_BRIGHTNESS_EVENT_CODE: u16 = 0x0006;
 
-pub const INTERNAL_BUTTON_PRESSED_EVENT_CODE: u16 = 0x0007;
-pub const INTERNAL_BUTTON_RELEASED_EVENT_CODE: u16 = 0x0008;
+pub const BUTTON_PRESSED_EVENT_CODE: u16 = 0x0007;
+pub const BUTTON_RELEASED_EVENT_CODE: u16 = 0x0008;
