@@ -3,12 +3,10 @@
 extern crate alloc;
 
 pub mod convert_packet;
-pub mod error;
 pub mod event;
 pub mod frame;
 pub mod interface;
 pub mod packet;
-pub mod packet_type;
 pub mod protocol;
 
 #[cfg(test)]
