@@ -56,9 +56,15 @@ impl<'a, I: Interface> Protocol<'a, I> {
     }
 
     pub fn send_packet(&mut self, packet: &Packet) -> Result<(), ProtocolError> {
-        match self.interface.try_send_packet(packet) {
-            Ok(_) => Ok(()),
-            Err(err) => Err(ProtocolError::InterfaceError(err)),
+        if packet.device_address == self.device_address
+        {
+            self.handle_packet(&packet, true);
+            Ok(())
+        } else {
+            match self.interface.try_send_packet(packet) {
+                Ok(_) => Ok(()),
+                Err(err) => Err(ProtocolError::InterfaceError(err)),
+            }
         }
     }
 
@@ -165,7 +171,7 @@ impl<'a, I: Interface> Protocol<'a, I> {
         return Ok(events);
     }
 
-    pub fn handle_packet(&mut self, packet: &Packet, owned_address: bool) {
+    fn handle_packet(&mut self, packet: &Packet, owned_address: bool) {
         for handler in self.handlers.values_mut() {
             if owned_address || handler.1 {
                 handler.0(packet, &mut self.interface);
