@@ -3,4 +3,4 @@ mod configurator_event_test;
 mod general_event_test;
 mod programmer_event_test;
 mod bcm_event_test;
-mod internal_event_test;
+mod button_event_test;
